Backy (backy v1.2.5)
Copy MarkdownSummary
Functions
Enqueue a job to be run immediately. The job will be persisted and then queued to be run immediately on the current node.
Enqueue a job to be run in delay milliseconds. The job will be persisted only.
Callback implementation for Application.start/2.
Touch a job to avoid it to timeout.
Functions
Enqueue a job to be run immediately. The job will be persisted and then queued to be run immediately on the current node.
This function returns only after the job has been persisted.
Enqueue a job to be run in delay milliseconds. The job will be persisted only.
This function returns only after the job has been persisted.
Callback implementation for Application.start/2.
Touch a job to avoid it to timeout.
This is intended to be called from within worker if your job is long.
For example, you might have an encoding job that take any time to finish
depending on the lenght of the video. You will set the max_runtime or the
worker to a couple of minutes, and in your perform function inside
the worker, you will call this function to extend your job lifetime.