mix backy.create_migration (backy v1.2.5)

This is an alternative to mix backy.setup. Instead of creating the backy table directly, this task generates an Ecto migration you can use in your project.

Usage (with defaults):

mix backy.create_migration --path=priv/repo/migrations/                                --name=backy_setup                                --repo=MyApp.Repo                                --table=jobs

Summary

Functions

Callback implementation for Mix.Task.run/1.

Functions

run(args)

Callback implementation for Mix.Task.run/1.